summaryrefslogtreecommitdiff
path: root/node/Switch.hpp
diff options
context:
space:
mode:
authorAdam Ierymenko <adam.ierymenko@gmail.com>2015-09-24 16:21:36 -0700
committerAdam Ierymenko <adam.ierymenko@gmail.com>2015-09-24 16:21:36 -0700
commitf69454ec9879a0b0a424f743ca144d1123ef7e99 (patch)
treea53bd7f8ebc2d164ead7d530a8e9ef17ffe73ddb /node/Switch.hpp
parent0e5aac6a117c28fde63f4cdb94e6c9fc415ca098 (diff)
downloadinfinitytier-f69454ec9879a0b0a424f743ca144d1123ef7e99.tar.gz
infinitytier-f69454ec9879a0b0a424f743ca144d1123ef7e99.zip
(1) Make ZT_ naming convention consistent (get rid of ZT1_), (2) Make local interface a full sockaddr_storage instead of an int identifier, which turns out to be better for multi-homing and other uses.
Diffstat (limited to 'node/Switch.hpp')
-rw-r--r--node/Switch.hpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/node/Switch.hpp b/node/Switch.hpp
index a8d89f41..3bdc0c47 100644
--- a/node/Switch.hpp
+++ b/node/Switch.hpp
@@ -79,12 +79,12 @@ public:
/**
* Called when a packet is received from the real network
*
* @param localInterfaceId Local interface ID or -1 for unspecified
* @param fromAddr Internet IP address of origin
* @param data Packet data
* @param len Packet length
*/
- void onRemotePacket(int localInterfaceId,const InetAddress &fromAddr,const void *data,unsigned int len);
+ void onRemotePacket(const InetAddress &localAddr,const InetAddress &fromAddr,const void *data,unsigned int len);
/**
* Called when a packet comes from a local Ethernet tap
@@ -141,10 +141,10 @@ public:
* Attempt NAT traversal to peer at a given physical address
*
* @param peer Peer to contact
* @param localInterfaceId Local interface ID or -1 if unspecified
* @param atAddr Address of peer
*/
- void rendezvous(const SharedPtr<Peer> &peer,int localInterfaceId,const InetAddress &atAddr);
+ void rendezvous(const SharedPtr<Peer> &peer,const InetAddress &localAddr,const InetAddress &atAddr);
/**
* Request WHOIS on a given address
@@ -181,8 +181,8 @@ public:
unsigned long doTimerTasks(uint64_t now);
private:
- void _handleRemotePacketFragment(int localInterfaceId,const InetAddress &fromAddr,const void *data,unsigned int len);
- void _handleRemotePacketHead(int localInterfaceId,const InetAddress &fromAddr,const void *data,unsigned int len);
+ void _handleRemotePacketFragment(const InetAddress &localAddr,const InetAddress &fromAddr,const void *data,unsigned int len);
+ void _handleRemotePacketHead(const InetAddress &localAddr,const InetAddress &fromAddr,const void *data,unsigned int len);
Address _sendWhoisRequest(const Address &addr,const Address *peersAlreadyConsulted,unsigned int numPeersAlreadyConsulted);
bool _trySend(const Packet &packet,bool encrypt,uint64_t nwid);
@@ -262,17 +262,17 @@ private:
struct ContactQueueEntry
{
ContactQueueEntry() {}
- ContactQueueEntry(const SharedPtr<Peer> &p,uint64_t ft,int liid,const InetAddress &a) :
+ ContactQueueEntry(const SharedPtr<Peer> &p,uint64_t ft,const InetAddress &laddr,const InetAddress &a) :
peer(p),
fireAtTime(ft),
inaddr(a),
- localInterfaceId(liid),
+ localAddr(laddr),
strategyIteration(0) {}
SharedPtr<Peer> peer;
uint64_t fireAtTime;
InetAddress inaddr;
- int localInterfaceId;
+ InetAddress localAddr;
unsigned int strategyIteration;
};
std::list<ContactQueueEntry> _contactQueue;
@@ -79,12 +79,12 @@ public:
* Called when a packet is received from the real network
*
- * @param localInterfaceId Local interface ID or -1 for unspecified
+ * @param localAddr Local interface address
* @param fromAddr Internet IP address of origin
* @param data Packet data
@@ -141,10 +141,10 @@ public:
*
* @param peer Peer to contact
- * @param localInterfaceId Local interface ID or -1 if unspecified
+ * @param localAddr Local interface address
* @param atAddr Address of peer
*/